@@ -1,6 +1,6 @@
-from box.copy import enhanced_copy
 from jinja2.runtime import Context, missing
 from .context import ObjectContext
+from .helpers import copy
 
 
 def new_context(environment, template_name, blocks,
@@ -11,14 +11,14 @@ def new_context(environment, template_name, blocks,
     if not isinstance(vrs, dict):
         parent = ObjectContext(vrs)
     if not shared:
-        parent = enhanced_copy(parent)
+        parent = copy(parent)
         for key, value in (globs or {}).items():
             if key not in parent:
                 # dict.setdefault doesn't work for ObjectContext
                 parent[key] = value
     if locs:
         if shared:
-            parent = enhanced_copy(parent)
+            parent = copy(parent)
         for key, value in locs.items():
             if (key[:2] == 'l_' and
                 value is not missing):
