@@ -1,6 +1,8 @@
 from packgram import ProjectModule
 
 
+# TODO: return target in render_file?
+# TODO: return render_dir?
 class ProjectModule(ProjectModule):
 
     # Attributes
@@ -8,7 +10,7 @@ class ProjectModule(ProjectModule):
     author = 'roll'
     author_email = 'roll@respect31.com'
     copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
-    description = 'Run-render is a run plugin.'
+    description = 'Run-render is a plugin for Run.'
     development_requires = ['packgram>=0.25']
     github_user = 'run-hub'
     install_requires = ['sugarbowl', 'runfile', 'run-function', 'jinja2']
@@ -19,4 +21,4 @@ class ProjectModule(ProjectModule):
     pypi_password_secure = 'pdoipmwGPkc5u/kw+wZSvLaPHtBEnBvswTWgloMTa5sqxZPek1xYKVHiXl3yYXl+ZRfIgNcDNInKzCN9TGl3R56BKuOmrMACy9WqqhI+vpEW+i8ewLDzSXZ4Y48chBMC2TJmRec4VQhME5RfCJFq7Fi7CjfclMSixxBQ0NYc4So='
     tests_require = ['nose', 'coverage']
     test_suite = 'nose.collector'
-    version = '0.4.0'
+    version = '0.5.0'
