@@ -1,6 +1,5 @@
 import unittest
 from unittest.mock import Mock
-from box.copy import enhanced_copy
 from importlib import import_module
 component = import_module('run_render.context')
 
@@ -26,6 +25,6 @@ class ObjectContextTest(unittest.TestCase):
         self.assertRaises(KeyError, self.context.__getitem__, 'no_key')
 
     def test___copy__(self):
-        context_copy = enhanced_copy(self.context)
+        context_copy = self.context.__copy__()
         self.assertEqual(context_copy['key1'], 'value1')
         self.assertEqual(context_copy['key2'], 'value2')
